@@ -4,6 +4,11 @@ import traceback
 import pandas as pd
 
 def getGenderByNames(names):
+
+    knn = joblib.load("model.pkl")
+    count_vect = joblib.load("vectorizer.pickle")
+    tfidf_transformer = joblib.load("idf.pickle")
+
     if type(names) == str:
         return print("please enter a list only")
     outPutNames = []
@@ -34,4 +39,3 @@ if __name__ == "__main__":
     print('idf loaded')
 
 
-print(getGenderByNames(["Gaston","Aime","Joseph"]).head())
\ No newline at end of file
